@@ -20,9 +20,9 @@ def get_report_name(self, report: Report) -> str:
         else str(None)
     )
     # File where the error occured
-    error_file = os.path.splitext(
-        os.path.basename(report.trace.error_position[0][0])
-    )[0].lower()
+    error_file = os.path.splitext(os.path.basename(report.trace.error_position[0][0]))[
+        0
+    ].lower()
 
     report_name = "id:{error_id},err:{error_type},err_file:{error_file},err_pos:{error_position}".format(
         error_id=error_id,
