@@ -1,8 +1,10 @@
-from frelatage.dictionary.dictionary import Dictionary
 import glob
 import os
+from typing import List, Any
+from frelatage.dictionary.dictionary import Dictionary
 
-def load_dictionary(dictionary_folder: str) -> bool:
+
+def load_dictionary(dictionary_folder: str) -> List[Any]:
     """
     Load all the dictionaries from the dictionary folder
     """
@@ -14,4 +16,4 @@ def load_dictionary(dictionary_folder: str) -> bool:
         for file in dictionary_files:
             # parse dictionary files
             dictionaries += dictionary.load_dictionary_from_file(file)
-    return dictionaries
\ No newline at end of file
+    return dictionaries
